Miscellaneous
=============

The :doc:`PyDynamic.misc` package provides various functions and methods which are
used in the examples and in some of the other implemented routines.

The package contains the following modules:

* :mod:`PyDynamic.misc.SecondOrderSystem`: tools for 2nd order systems
* :mod:`PyDynamic.misc.filterstuff`: tools for digital filters
* :mod:`PyDynamic.misc.testsignals`: test signals
* :mod:`PyDynamic.misc.noise`: noise related functions
* :mod:`PyDynamic.misc.tools`: miscellaneous useful helper functions

Tools for 2nd order systems
---------------------------

.. automodule:: PyDynamic.misc.SecondOrderSystem
    :members:

Tools for digital filters
-------------------------

.. automodule:: PyDynamic.misc.filterstuff
    :members:

Test signals
------------

.. automodule:: PyDynamic.misc.testsignals
    :members:

Noise related functions
-----------------------

.. automodule:: PyDynamic.misc.noise
    :members:

Miscellaneous useful helper functions
-------------------------------------

.. automodule:: PyDynamic.misc.tools
    :members:
